//
//  JEDownloader.m
//  JEDownloader
//
//  Copyright 2012 Jonathan Ellis
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "JEDownloader.h"

@implementation JEDownloader

@synthesize delegate;
@synthesize timeout;
@synthesize tag;
@synthesize context;

- (id)init {
    if (self = [super init]) {
        timeout = 30.0;
    }
    return self;
}

- (void)downloadFromURL:(NSURL *)url postData:(NSDictionary *)postData {
    
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:url cachePolicy:NSURLRequestUseProtocolCachePolicy timeoutInterval:timeout]; 
    [request setHTTPMethod:@"POST"];
    
    NSString *queryString = [postData queryString];
    
    [request setHTTPBody:[queryString dataUsingEncoding:NSUTF8StringEncoding]];
    [request setValue:@"application/x-www-form-urlencoded; charset=UTF-8" forHTTPHeaderField:@"Content-Type"];
    
    NSURLConnection *connection = [[NSURLConnection alloc] initWithRequest:request delegate:self]; 
    if (connection) {
        receivedData = [NSMutableData data];
    } else {
        if ([delegate respondsToSelector:@selector(downloader:failedWithError:)])
            [delegate downloader:self failedWithError:nil];
    }
}

- (void)downloadFromURL:(NSURL *)url {
    
    NSURLRequest *request = [NSURLRequest requestWithURL:url cachePolicy:NSURLRequestUseProtocolCachePolicy timeoutInterval:timeout];
    
    NSURLConnection *connection = [[NSURLConnection alloc] initWithRequest:request delegate:self];
    if (connection) {
        receivedData = [NSMutableData data];
    } else {
        if ([delegate respondsToSelector:@selector(downloader:failedWithError:)])
            [delegate downloader:self failedWithError:nil];
    }
}

#pragma mark NSURLConnectionDelegate methods

- (void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response {
    [receivedData setLength:0];
}

- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data {
    [receivedData appendData:data];
}

- (void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error {
    connection = nil; 
    receivedData = nil;
    
    if ([delegate respondsToSelector:@selector(downloader:failedWithError:)])
        [delegate downloader:self failedWithError:error];
}

- (void)connectionDidFinishLoading:(NSURLConnection *)connection {
    
    if ([delegate respondsToSelector:@selector(downloader:finishedWithData:)])
        [delegate downloader:self finishedWithData:receivedData];
    
    connection = nil;
    receivedData = nil;
}

@end