//
//  NSDictionary+QueryString.m
//  JEDownloader
//
//  Copyright 2012 Jonathan Ellis
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

@implementation NSDictionary (QueryStringBuilder)

+ (NSString *)escapeString:(NSString *)string {
    CFStringRef stringRef = (__bridge_retained CFStringRef)string;
    NSString *result = (__bridge_transfer NSString *)CFURLCreateStringByAddingPercentEscapes(NULL, stringRef, NULL, NULL, kCFStringEncodingUTF8);
    CFRelease(stringRef);
    return result;
}

- (NSString *)queryString {

    NSMutableString *result;
    
    for (NSString *key in self) {
        NSString *value = [self valueForKey:key];
        
        NSString *escapedKey = [NSDictionary escapeString:key];
        NSString *escapedValue = [NSDictionary escapeString:value];
        
        if (!result) result = [NSMutableString stringWithFormat:@"%@=%@", escapedKey, escapedValue];
        else [result appendFormat:@"&%@=%@", escapedKey, escapedValue];
    }
    
    return result;
}

@end