//
//  ViewController.m
//  JEDownloaderSample
//
//  Copyright 2012 Jonathan Ellis
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "ViewController.h"


@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    // EXAMPLE 1: Download Google HTML
    JEDownloader *googleDownloader = [[JEDownloader alloc] init];
    googleDownloader.delegate = self;
    googleDownloader.context = @"Google";
    [googleDownloader downloadFromURL:[NSURL URLWithString:@"http://www.google.com/"]];
    
    // EXAMPLE 2: Send some POST data
    JEDownloader *testPostDownloader = [[JEDownloader alloc] init];
    testPostDownloader.delegate = self;
    testPostDownloader.context = @"TestPost";
    NSDictionary *postData = [NSDictionary dictionaryWithObject:@"haha" forKey:@"loser"];
    [testPostDownloader downloadFromURL:[NSURL URLWithString:@"http://posttestserver.com/post.php"] postData:postData];
    
}

#pragma mark - JEDownloaderDelegate methods

- (void)downloader:(JEDownloader *)downloader finishedWithData:(NSData *)data {
    NSString *string = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
    
    if ([downloader.context isEqualToString:@"Google"]) { // Disambiguate downloaders by their context
        NSLog(@"Google's HTML is: %@", string);
    } else {
        NSLog(@"The response from the test POST server is: %@", string);
    }
}

- (void)downloader:(JEDownloader *)downloader failedWithError:(NSError *)error {
    NSLog(@"Downloader error: %@", error.description);
}


@end
