# JEDownloader

JEDownloader is a super-duper easy-peasy HTTP library for Cocoa. It is really little more than a wafer-thin wrapper around `NSURLRequest` and `NSURLConnection` that reduces all of that boring repetitive code you have to write every time you want to write some simple code to make a call to an API, or download a small file.

The foremost goal of JEDownloader is _simplicity_ and includes as little overhead or complexity as possible in order to just _get the job done_. JEDownloader is absolutely _not_ an all-singing, all-dancing fully-featured HTTP library for your next enterprise project. For that, I can recommend the fine [ASIHTTPRequest](https://github.com/pokeb/asi-http-request) library which supports a truly impressive range of features like partial downloads, cookies, and more.

But what JEDownloader _does_ do well is simplicity -- it's a library so simple, your grandmother could use it. (In fact, she probably does.)

Downloading (or calling an API, they're equivalent really!) is as done with a simple one-argument call: `[downloader downloadFromURL:[NSURL URLWithString:@"http://www.google.com/"]];`. That's it! If you want to make a POST call, just use the same call but use the `postData:` parameter and add your parameters as an `NSDictionary` and JEDownloader will take care of the rest.

JEDownloader is fully asynchronous, and once the download is complete, it will ping your delegate and return the result from the server as an `NSData` object.

There are also other nice features included, like tagging your download with an `int` tag, or `id` context so you can disambiguate the server responses in the callback, and there are plenty more features (GET variables, progress callbacks, etc.) coming soon... without compromising the simplicity, of course!

## Getting Started

To begin, either check out the code from the repository, or if you're _really_ lazy, just [download the latest code as a ZIP file](https://github.com/jonathanellis/pegasus/zipball/master) to get going right away.

You'll find the relevant code in the `JEDownloader` directory. You can simply drag and drop this folder into your project in Xcode (make sure you copy the files into your development folder!) and then simply import JEDownloader into your project by adding the following `import` directive to your class _or_ to your project's precompiled header (`.pch`) file to make it available project-wide:-

	import "JEDownloader.h"
	
...and you're ready to go!

## Sample Application

JEDownloader comes with a (very!) basic sample application showing you how to use the code in a typical iOS project. You can find the sample by opening the `JEDownloaderSample` in the repository.

There are two examples, one using GET and one using POST which you can find in the `ViewController.m` file.

You shouldn't include this code when distributing JEDownloader with your software, it's there for development reference only!

## License Agreements

Copyright 2012 Jonathan Ellis

Licensed under the Apache License, Version 2.0 (the "License");
you may not use these files except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.